#!/bin/bash
#set -vx
#  
# Description:
#   General overall settings required by the monitoring system.
#   These settings are for all environments at a particular site.
#
#
#  Author: Tom Jurcic
#  Date:   12/01/2001
#
##############################################################################



#----------------------------------------------------------------------------

##############################################################################
#
# Application Global Constants
#
##############################################################################



#
# Main Application Release No.
#
test -z "$RR_C_REDALERT_RELEASE"  \
  &&    export RR_C_REDALERT_RELEASE=1.3			; typeset -r RR_C_REDALERT_RELEASE


#
# Module Name
#
# Because of the cyclic module dependancy between this module and the Runlevel
# module, a "conditional" approach is being applied this and other module-name variables.
#
test -z "$RR_C_MOD_NAME_CONSTANTS"  \
  &&    RR_C_MOD_NAME_CONSTANTS="rr_lib_constants" ; typeset -r RR_C_MOD_NAME_CONSTANTS



#(for debugging) Lists all readonly variables at the end of tracing script execution.
#typeset -r
#sleep 3


#
# Module Version
#
test -z "$RR_C_MOD_VER_CONSTANTS"  \
  &&    RR_C_MOD_VER_CONSTANTS="$Revision:   1.3  $" ; typeset -r RR_C_MOD_VER_CONSTANTS


#
# Application Directory references
#
test -z   "$RR_C_BASE_LIB_DIR"  \
  && export RR_C_BASE_LIB_DIR="./base_library"	; typeset -r RR_C_BASE_LIB_DIR


#
#Exit codes
#
#-*- Global across all application components -*-
#

# OS Errors
#=======================

if [ -z "$RR_EXIT2"  ]
then

export RR_EXIT2=2;   typeset -ir RR_EXIT2   # Error while executing a OS command.
export RR_EXIT3=3;   typeset -ir RR_EXIT3   # Missing configfile, executables or unset environment variables.
export RR_EXIT8=8;   typeset -ir RR_EXIT8   # Incorrect access privileges to a file.
export RR_EXIT11=11; typeset -ir RR_EXIT11  # Filesystem/s has capacity problems.
export RR_EXIT24=24; typeset -ir RR_EXIT24  # Could not find target file.
export RR_EXIT25=25; typeset -ir RR_EXIT25  # Incorrect environment variable values.


# Application Errors
#=======================
export RR_EXIT1=1;   typeset -ir RR_EXIT1   # Generic, Usage error or Execution termination by the user. 
export RR_EXIT4=4;   typeset -ir RR_EXIT4   # Incorrect installation owner.
export RR_EXIT7=7;   typeset -ir RR_EXIT7   # Incorrect number of arguments
export RR_EXIT9=9;   typeset -ir RR_EXIT9   # Unsuccessful tablespace creation for repository
export RR_EXIT10=10; typeset -ir RR_EXIT10  # Unsuccessful creation repository user
export RR_EXIT12=12; typeset -ir RR_EXIT12  # Missing background process
export RR_EXIT13=13; typeset -ir RR_EXIT13  # Database ping failed
export RR_EXIT14=14; typeset -ir RR_EXIT14  # Database install ofschema objects failed
export RR_EXIT16=16; typeset -ir RR_EXIT16  # Invalid Run-Level class
export RR_EXIT15=15; typeset -ir RR_EXIT15  # Database check function failed
export RR_EXIT17=17; typeset -ir RR_EXIT17  # Invalid Run-Level settings
export RR_EXIT18=18; typeset -ir RR_EXIT18  # Not the expected Run-Level , skip the current task 
export RR_EXIT19=19; typeset -ir RR_EXIT19  # Configuration parameter file contains incorrect values 
export RR_EXIT20=20; typeset -ir RR_EXIT20  # Database ratio problem exists
export RR_EXIT21=21; typeset -ir RR_EXIT21  # Database space problem exists
export RR_EXIT22=22; typeset -ir RR_EXIT22  # Database parameter problem exists
export RR_EXIT23=23; typeset -ir RR_EXIT23  # Database alert-log problem exists
export RR_EXIT26=26; typeset -ir RR_EXIT26  # Run-level class check has failed.
export RR_EXIT27=27; typeset -ir RR_EXIT27  # Job abort signalled.
export RR_EXIT28=28; typeset -ir RR_EXIT28  # Alarm-level group check has failed.
export RR_EXIT29=29; typeset -ir RR_EXIT29  # Invalid alarm-level settings
export RR_EXIT31=31; typeset -ir RR_EXIT31  # Sqlplus errored.
export RR_EXIT32=32; typeset -ir RR_EXIT32  # RedAlert polling-job clash possible.
export RR_EXIT33=33; typeset -ir RR_EXIT33  # Function failed earlier on.
export RR_EXIT34=34; typeset -ir RR_EXIT34  # Maintenance of Alertlog failed.
export RR_EXIT35=35; typeset -ir RR_EXIT35  # Database abnormal sessions exist
export RR_EXIT36=36; typeset -ir RR_EXIT36  # Database rate-of-activity problem exists


# Net Errors
#=======================
export RR_EXIT5=5;   typeset -ir RR_EXIT5   # Listener unreachable
export RR_EXIT6=6;   typeset -ir RR_EXIT6   # Email was not sent due to an error
export RR_EXIT30=30; typeset -ir RR_EXIT30  # Email was not read due to an error


#*** Current Max Err#: 35

fi



#----------------------------------------------------------------------------

##############################################################################
#
# Import Modules
#
##############################################################################




test "$RR_C_CFG_SITE_NAME" = ""  \
  &&  . ./rr_cfg_site.sh

test "$RR_C_MOD_LIB_SYSTEMTYPE" = ""  \
  &&  . $RR_C_BASE_LIB_DIR/SystemType.sh

test "$RR_C_MOD_NAME_RUNLVL" = ""  \
  &&  . ./rr_lib_runlevel.sh


#----------------------------------------------------------------------------

##############################################################################
#
# local functions
#
##############################################################################



########
#
########
rr_const_usage()
{
2>&1 \ 
(
echo "${0},rr_const_usage:" 
echo "Usage :  ${0}  ... ";
echo "Example: ${0} ";
echo "
   ORACLE_HOME must be set.
   This variable can be set from the environment or passed as an argument.
   ORACLE_HOME is the database software location that \"${0}\" will 
   use to connect to the local target database.
" 
) 

sleep 3
return ${RR_EXIT1};
}

typeset -fx rr_const_usage



########
#
########
rr_const_chk_env()
{
if [ -z "$ORACLE_HOME" ]; then
    rr_const_usage;
    return ${RR_EXIT3};
fi
}

typeset -fx rr_const_chk_env



########
#
########
rr_constants_unix()
{
typeset FUNCT_NAME="rr_constants_unix()"

# Main dir. paths
export RR_C_BINP=$RR_C_CFG_BINP
#eg. /bin

export RR_C_UBINP=$RR_C_CFG_UBINP
#eg. /usr/bin

export RR_C_USBINP=$RR_C_CFG_USBINP
#eg. /usr/sbin

#Commands
case `SystemType` in
 AIX )  
   export       RR_C_DF="$RR_C_UBINP/df -kP"	; typeset -r RR_C_DF
   export RR_C_NSLOOKUP=$RR_C_UBINP/nslookup	; typeset -r RR_C_NSLOOKUP
   export  RR_C_NETSTAT=$RR_C_UBINP/netstat	; typeset -r RR_C_NETSTAT	
   ;;
 DECOSF )  
   export       RR_C_DF="$RR_C_UBINP/df -kP"	; typeset -r RR_C_DF
   export RR_C_NSLOOKUP=$RR_C_UBINP/nslookup	; typeset -r RR_C_NSLOOKUP
   export  RR_C_NETSTAT=$RR_C_USBINP/netstat	; typeset -r RR_C_NETSTAT	
   ;;
 HP )  
   export       RR_C_DF=$RR_C_UBINP/bdf		; typeset -r RR_C_DF
   export RR_C_NSLOOKUP=$RR_C_BINP/nslookup	; typeset -r RR_C_NSLOOKUP
   export  RR_C_NETSTAT=$RR_C_UBINP/netstat	; typeset -r RR_C_NETSTAT	
   ;;
 * )
   export       RR_C_DF="$RR_C_UBINP/df -k"	; typeset -r RR_C_DF
   export RR_C_NSLOOKUP=$RR_C_USBINP/nslookup	; typeset -r RR_C_NSLOOKUP
   export  RR_C_NETSTAT=$RR_C_UBINP/netstat	; typeset -r RR_C_NETSTAT	
   ;;
esac

export RR_C_IPCONFIG=$RR_C_USBINP/ifconfig	; typeset -r RR_C_IPCONFIG

export       RR_C_CP=$RR_C_BINP/cp		; typeset -r RR_C_CP
export       RR_C_MV=$RR_C_BINP/mv		; typeset -r RR_C_MV
export       RR_C_RM=$RR_C_BINP/rm		; typeset -r RR_C_RM
export      RR_C_SED=$RR_C_BINP/sed		; typeset -r RR_C_SED
export     RR_C_EXPR=$RR_C_BINP/expr		; typeset -r RR_C_EXPR
export  RR_C_DIRNAME=$RR_C_BINP/dirname		; typeset -r RR_C_DIRNAME
export RR_C_BASENAME=$RR_C_BINP/basename	; typeset -r RR_C_BASENAME	

export       RR_C_BC=$RR_C_UBINP/bc       ; typeset -r RR_C_BC
export       RR_C_ID=$RR_C_UBINP/id		; typeset -r RR_C_ID
export       RR_C_LS=$RR_C_UBINP/ls		; typeset -r RR_C_LS
export       RR_C_PS=$RR_C_UBINP/ps		; typeset -r RR_C_PS
export       RR_C_TR=$RR_C_UBINP/tr		; typeset -r RR_C_TR
export       RR_C_WC=$RR_C_UBINP/wc		; typeset -r RR_C_WC
export      RR_C_AWK=$RR_C_UBINP/awk		; typeset -r RR_C_AWK
export      RR_C_CAT=$RR_C_UBINP/cat		; typeset -r RR_C_CAT
export      RR_C_CUT=$RR_C_UBINP/cut		; typeset -r RR_C_CUT
export      RR_C_TAR=$RR_C_UBINP/tar 		; typeset -r RR_C_TAR
export      RR_C_TEE=$RR_C_UBINP/tee		; typeset -r RR_C_TEE
export     RR_C_DATE=$RR_C_UBINP/date		; typeset -r RR_C_DATE
export     RR_C_FIND=$RR_C_UBINP/find		; typeset -r RR_C_FIND
export     RR_C_GREP=$RR_C_UBINP/grep		; typeset -r RR_C_GREP
export     RR_C_HEAD=$RR_C_UBINP/head		; typeset -r RR_C_HEAD
export     RR_C_MAIL=$RR_C_UBINP/mailx		; typeset -r RR_C_MAIL
export     RR_C_SORT=$RR_C_UBINP/sort		; typeset -r RR_C_SORT
export     RR_C_STTY=$RR_C_UBINP/stty		; typeset -r RR_C_STTY
export     RR_C_SYNC=$RR_C_UBINP/sync		; typeset -r RR_C_SYNC
export     RR_C_TAIL=$RR_C_UBINP/tail		; typeset -r RR_C_TAIL
export     RR_C_UNIQ=$RR_C_UBINP/uniq		; typeset -r RR_C_UNIQ
export    RR_C_CHMOD=$RR_C_UBINP/chmod		; typeset -r RR_C_CHMOD
export    RR_C_CHOWN=$RR_C_UBINP/chown		; typeset -r RR_C_CHOWN
export    RR_C_EGREP=$RR_C_UBINP/egrep		; typeset -r RR_C_EGREP
export    RR_C_MKDIR=$RR_C_UBINP/mkdir		; typeset -r RR_C_MKDIR
export    RR_C_RMDIR=$RR_C_UBINP/rmdir		; typeset -r RR_C_RMDIR
export    RR_C_SLEEP=$RR_C_UBINP/sleep		; typeset -r RR_C_SLEEP
export    RR_C_SPLIT=$RR_C_UBINP/split		; typeset -r RR_C_SPLIT
export    RR_C_TOUCH=$RR_C_UBINP/touch		; typeset -r RR_C_TOUCH
export    RR_C_UNAME=$RR_C_UBINP/uname		; typeset -r RR_C_UNAME
export    RR_C_XARGS=$RR_C_UBINP/xargs		; typeset -r RR_C_XARGS
export   RR_C_PRINTF=$RR_C_UBINP/printf		; typeset -r RR_C_PRINTF
export   RR_C_WHOAMI=$RR_C_UBINP/whoami		; typeset -r RR_C_WHOAMI
export RR_C_COMPRESS="$RR_C_UBINP/compress -c"	; typeset -r RR_C_COMPRESS	
export RR_C_HOSTNAME=$RR_C_UBINP/hostname	; typeset -r RR_C_HOSTNAME	
export RR_C_UUDECODE=$RR_C_BINP/uudecode	; typeset -r RR_C_UUDECODE	
export RR_C_UUENCODE=$RR_C_UBINP/uuencode	; typeset -r RR_C_UUENCODE	

typeset -r RR_C_BINP
typeset -r RR_C_UBINP
typeset -r RR_C_USBINP
}

typeset -fx rr_constants_unix




########
#
########
rr_constants_nt()
{
typeset FUNCT_NAME="rr_constants_nt()"

# Main dir. paths

export RR_C_BINP=$RR_C_CFG_BINP
#eg. C:/progra~1/mkstoo~1/mksnt
#eg. $ROOTDIR/mksnt
#eg. /usr/bin

export RR_C_USBINP=$RR_C_CFG_USBINP
#eg. /usr/sbin

export RR_C_RESKITP=$RR_C_CFG_RESKITP
#eg. C:/progra~1/rksupport
#eg. G:/rr/redalert/bin/W2K/NT4_extras  for WIN2000

export RR_C_WINNTP=$RR_C_CFG_WINNTP

# For MKS Toolkit
export sendmail="$RR_C_BINP/smtpmail.exe -h $RR_C_CFG_SMTP_SVR"
#eg. "mail.rr.net.au"  (IP address of Smtp Mail Server)
#Used by mailx and similar utilities.

if [ "$TERM" = "nutc" ]
then
  export     RR_C_MAIL="${sendmail}"		; typeset -r RR_C_MAIL  #chng1.1
  #export    RR_C_MAIL=$RR_C_BINP/mailx		; typeset -r RR_C_MAIL  #Had problems on some NT sites
  export RR_C_COMPRESS=$RR_C_BINP/"mkszip -fc"	; typeset -r RR_C_COMPRESS	
else
  export     RR_C_MAIL=$RR_C_WINNTP/blat	; typeset -r RR_C_MAIL
  #export    RR_C_MAIL=$RR_C_USBINP/ssmtp	; typeset -r RR_C_MAIL
  export RR_C_COMPRESS=$RR_C_BINP/"gzip -c"	; typeset -r RR_C_COMPRESS	
fi  #End chng1.3

#Commands
export       RR_C_BC=$RR_C_BINP/bc        ; typeset -r RR_C_BC
export       RR_C_CP=$RR_C_BINP/cp		; typeset -r RR_C_CP
export       RR_C_DF="$RR_C_BINP/df -kP"	; typeset -r RR_C_DF	
export       RR_C_ID=$RR_C_BINP/id		; typeset -r RR_C_ID
export       RR_C_LS=$RR_C_BINP/ls		; typeset -r RR_C_LS
export       RR_C_MV=$RR_C_BINP/mv		; typeset -r RR_C_MV
export       RR_C_PS=$RR_C_BINP/ps		; typeset -r RR_C_PS
export       RR_C_RM=$RR_C_BINP/rm		; typeset -r RR_C_RM
export       RR_C_TR=$RR_C_BINP/tr		; typeset -r RR_C_TR
export       RR_C_WC=$RR_C_BINP/wc		; typeset -r RR_C_WC
export      RR_C_AWK=$RR_C_BINP/awk		; typeset -r RR_C_AWK
export      RR_C_CAT=$RR_C_BINP/cat		; typeset -r RR_C_CAT
export      RR_C_CUT=$RR_C_BINP/cut		; typeset -r RR_C_CUT
export      RR_C_SED=$RR_C_BINP/sed		; typeset -r RR_C_SED
export      RR_C_TAR=$RR_C_BINP/tar		; typeset -r RR_C_TAR
export      RR_C_TEE=$RR_C_BINP/tee		; typeset -r RR_C_TEE
export     RR_C_DATE=$RR_C_BINP/date		; typeset -r RR_C_DATE
export     RR_C_EXPR=$RR_C_BINP/expr		; typeset -r RR_C_EXPR
export     RR_C_FIND=$RR_C_BINP/find		; typeset -r RR_C_FIND
export     RR_C_GREP=$RR_C_BINP/grep		; typeset -r RR_C_GREP
export     RR_C_HEAD=$RR_C_BINP/head		; typeset -r RR_C_HEAD
export     RR_C_SORT=$RR_C_BINP/sort		; typeset -r RR_C_SORT
export     RR_C_STTY=$RR_C_BINP/stty		; typeset -r RR_C_STTY
export     RR_C_SYNC=$RR_C_BINP/sync		; typeset -r RR_C_SYNC
export     RR_C_TAIL=$RR_C_BINP/tail		; typeset -r RR_C_TAIL
export     RR_C_UNIQ=$RR_C_BINP/uniq		; typeset -r RR_C_UNIQ
export    RR_C_CHMOD=$RR_C_BINP/chmod		; typeset -r RR_C_CHMOD
export    RR_C_CHOWN=$RR_C_BINP/chown		; typeset -r RR_C_CHOWN
export    RR_C_EGREP=$RR_C_BINP/egrep		; typeset -r RR_C_EGREP
export    RR_C_MKDIR=$RR_C_BINP/mkdir		; typeset -r RR_C_MKDIR
export    RR_C_RMDIR=$RR_C_BINP/rmdir		; typeset -r RR_C_RMDIR
export    RR_C_SLEEP=$RR_C_BINP/sleep		; typeset -r RR_C_SLEEP
export    RR_C_SPLIT=$RR_C_BINP/split		; typeset -r RR_C_SPLIT
export    RR_C_TOUCH=$RR_C_BINP/touch		; typeset -r RR_C_TOUCH
export    RR_C_UNAME=$RR_C_BINP/uname		; typeset -r RR_C_UNAME
export    RR_C_XARGS=$RR_C_BINP/xargs		; typeset -r RR_C_XARGS
export   RR_C_PRINTF=$RR_C_BINP/printf		; typeset -r RR_C_PRINTF
export   RR_C_WHOAMI=$RR_C_BINP/whoami		; typeset -r RR_C_WHOAMI
export  RR_C_DIRNAME=$RR_C_BINP/dirname		; typeset -r RR_C_DIRNAME
export RR_C_BASENAME=$RR_C_BINP/basename	; typeset -r RR_C_BASENAME	
export RR_C_UUDECODE=$RR_C_BINP/uudecode	; typeset -r RR_C_UUDECODE	
export RR_C_UUENCODE=$RR_C_BINP/uuencode	; typeset -r RR_C_UUENCODE	


export  RR_C_DUMPEL=$RR_C_RESKITP/dumpel	; typeset -r RR_C_DUMPEL
export RR_C_MEMSNAP=$RR_C_RESKITP/memsnap	; typeset -r RR_C_MEMSNAP
export      RR_C_SC=$RR_C_RESKITP/sc		; typeset -r RR_C_SC

export RR_C_HOSTNAME=$RR_C_WINNTP/hostname	; typeset -r RR_C_HOSTNAME
export RR_C_IPCONFIG=$RR_C_WINNTP/ipconfig	; typeset -r RR_C_IPCONFIG
export      RR_C_NET=$RR_C_WINNTP/net		; typeset -r RR_C_NET
export  RR_C_NETSTAT=$RR_C_WINNTP/netstat	; typeset -r RR_C_NETSTAT
export RR_C_NSLOOKUP=$RR_C_WINNTP/nslookup	; typeset -r RR_C_NSLOOKUP

typeset -r sendmail
typeset -r RR_C_BINP
typeset -r RR_C_USBINP
typeset -r RR_C_RESKITP
typeset -r RR_C_WINNTP
}

typeset -fx rr_constants_nt




#----------------------------------------------------------------------------

##############################################################################
#
# Module Functions
#
##############################################################################



########
#
########
rr_constants_os()
{
typeset FUNCT_NAME="rr_constants_os()"

rr_const_chk_env;
SystemType ;
case `SystemType` in
  Windows_NT )   
      rr_constants_nt      ;;
  * )            
      rr_constants_unix    ;;
esac
}

typeset -fx rr_constants_os




########
#
########
rr_constants_app()
{
typeset FUNCT_NAME="rr_constants_app()"


##############################
# Available Sections:
# -------------------
#
# Main Settings
# Main Directory locations
# Alertlog House-cleaning Settings
# Monthly House-cleaning Configuration
# Mail Configuration
# Main File References
# DB Alive Check Settings
# Database Category Types
# Banner Types
# Session Probe Types
# Cycle Modes for Jobs *** not fully functional - might be pruned ***
# Run Level Settings
# Alarm Types
# Threshold Settings
#
##############################



# Main Settings
##############################


# Site-specific rr Application Settings
#

export RR_C_APPLIC_OWNER=$RR_C_CFG_APPLIC_OWNER	; typeset -r RR_C_APPLIC_OWNER
#eg. oracle

export RR_C_SITE_NAME=$RR_C_CFG_SITE_NAME	; typeset -r RR_C_SITE_NAME
#eg. rrHQ



# Main Directory locations
##############################

export RR_C_BASE_DIR=$RR_C_CFG_BASE_DIR
#eg. d:/oracle/rr/redalert
#eg. /u01/app/oracle/rr/redalert

export  RR_C_SQLDIR=$RR_C_BASE_DIR/sql			
export  RR_C_TMPDIR=$RR_C_BASE_DIR/temp			
export  RR_C_LOGDIR=$RR_C_BASE_DIR/log			
export RR_C_MAILDIR=$RR_C_BASE_DIR/mail			
export  RR_C_ARCDIR=$RR_C_BASE_DIR/arch			



# Alertlog House-cleaning Settings
#######################################

export RR_C_AERTLOG_CLEAROUT_SIZE="11000"	; typeset -r RR_C_AERTLOG_CLEAROUT_SIZE
# Size in bytes.



# Monthly House-cleaning Configuration
#######################################

export RR_C_LOG_CLEAROUT_DELAY="25"		; typeset -r RR_C_LOG_CLEAROUT_DELAY
# Delay in days.

export RR_C_LOGFILE_CLEAROUT_DELAY="10"		; typeset -r RR_C_LOGFILE_CLEAROUT_DELAY
# Delay in days. They should already been archived.

export RR_C_TEMPFILE_CLEAROUT_DELAY="14"	; typeset -r RR_C_TEMPFILE_CLEAROUT_DELAY
# Delay in days.

export RR_C_BAKUPDIR_CLEAROUT_DELAY="40"	; typeset -r RR_C_BAKUPDIR_CLEAROUT_DELAY
# Delay in days.

export RR_C_DUMPFILE_SPLIT_SIZE="256k"	; typeset -r RR_C_DUMPFILE_SPLIT_SIZE
# Chunk-size used in splitting the exported and compressed repository dump file.

export RR_C_NT_TEMPFILE_CLEAROUT_DELAY="14"	; typeset -r RR_C_NT_TEMPFILE_CLEAROUT_DELAY
# Delay in days.

export     RR_C_BAKREPOS_BYPASS_EXP_TEMPLATE="$RR_C_BASE_DIR/@.ei_eu_bypass_REDALERT.flg"
typeset -r RR_C_BAKREPOS_BYPASS_EXP_TEMPLATE
# The @ symbol is replaced with DB name
# To create this file ->  e.g. $ touch GPD.ei_eu_bypass_REDALERT.flg

export     RR_C_BAKREPOS_IGNORE_ERR_EXP_TEMPLATE="$RR_C_BASE_DIR/@.ei_eu_err_ignore_REDALERT.flg"
typeset -r RR_C_BAKREPOS_IGNORE_ERR_EXP_TEMPLATE
# The @ symbol is replaced with DB name
# To create this file ->  e.g. $ touch GPD.ei_eu_bypass_REDALERT.flg

export     RR_C_BAKREPOS_PARAM_FILE="ei_eu_REDALERT"
typeset -r RR_C_BAKREPOS_PARAM_FILE
# Repository Export Configuration

export     RR_C_BAKREPOS_DELAY=900
#export    RR_C_BAKREPOS_DELAY=0
typeset -r RR_C_BAKREPOS_DELAY
# Repository Export Delay time
# wait for 15 minutes  

export     RR_C_EXP_PREFIX_NAME="bak__repos_"

export     RR_C_EXP_DIR_PREFIX="$RR_C_ARCDIR/$RR_C_EXP_PREFIX_NAME"
typeset -r RR_C_EXP_DIR_PREFIX
# Repository Export Dump Dir Prefix


typeset -r RR_C_EXP_PREFIX_NAME




# Mail Configuration
##############################

export RR_C_MAIL_DEST="$RR_C_CFG_MAIL_DEST"	; typeset -r RR_C_MAIL_DEST
#eg. If >1 mail destinations are required, then, setup a double-quoted and comma-seperated list
#eg. monitor@rr.net.au

export RR_C_MAIL_DEST_ALERTS="$RR_C_CFG_MAIL_DEST_ALERTS"	; typeset -r RR_C_MAIL_DEST_ALERTS
#eg. (Optional) Leave it blank if it is not needed.
#eg. If >1 mail destinations are required, then, setup a double-quoted and comma-seperated list
#eg. support@offsite.com

export RR_C_MAIL_PROFILE="$RR_C_CFG_MAIL_PROFILE" ; typeset -r RR_C_MAIL_PROFILE
#eg. oracle (source user's mail account, usually the same the owner)

export RR_C_MAIL_PROFILE_NONE="x"		; typeset -r RR_C_MAIL_PROFILE_NONE

export RR_C_MAIL_PROCESS_FILE="msg_process"



# Main File References
##############################

# Bypass Flag File
#

export     RR_C_BYPASS_FILE=$RR_C_BASE_DIR/redalert_skip_jobs.flg
typeset -r RR_C_BYPASS_FILE


# Configuration File
#

export     RR_C_CONFIG_FILE=$RR_C_BASE_DIR/rr_cfg_db.txt
typeset -r RR_C_CONFIG_FILE


# Configuration File - Parameter Count
#

export     RR_C_PARAMETER_FIELD_CNT=20	; typeset -ir RR_C_PARAMETER_FIELD_CNT


# Filesystem Exclusion File
#

export     RR_C_EXCLUDE_OS_FILSYS_FILE=$RR_C_BASE_DIR/rr_cfg_exclude_filsys.sed
typeset -r RR_C_EXCLUDE_OS_FILSYS_FILE


# Sqlplus Errors File Prefix
#
export     RR_C_SQLPLUS_ERR_FILE_PREFIX=$RR_C_TMPDIR/sqlplus_err
typeset -r RR_C_SQLPLUS_ERR_FILE_PREFIX



# RedAlert Timeout Settings for Active Jobs
############################################

# Active-Check by "rr_admin_backuplogs.sh"
#
export      RR_C_DELAY_TIMOUT_BAKUPLOGS=60
typeset -ir RR_C_DELAY_TIMOUT_BAKUPLOGS

# Active-Check by "rr_process_alert_job.sh"
#
export      RR_C_DELAY_TIMOUT_JOB_COORDINATOR=60
typeset -ir RR_C_DELAY_TIMOUT_JOB_COORDINATOR



# DB Alive Check Settings
##############################

# Sqlplus Alive-Check File Prefix
#
export     RR_C_SQLPLUS_ALIVE_FILE_PREFIX=$RR_C_TMPDIR/sqlplus_not_hanging
typeset -r RR_C_SQLPLUS_ALIVE_FILE_PREFIX

# Sqlplus Alive-Check timeout
#
export      RR_C_SQLPLUS_ALIVE_TIMEOUT=90   ; typeset -ir RR_C_SQLPLUS_ALIVE_TIMEOUT



# Database Category Types
##############################

export RR_C_DB_TYPE_SKIP="SKP"
export RR_C_DB_TYPE_HYBRID="HYB"
export RR_C_DB_TYPE_TRANSACTIONAL="TXN"
export RR_C_DB_TYPE_DATAWAREHOUSE="DWH"



# Banner Types
##############################

# For errors at the end of a run-level class
export RR_C_BANNER_ERROR_RUNLEVEL="!!--!!--!!--!!--!!"

# For errors with goups of component procedures
export RR_C_BANNER_ERROR_SECTION="!-!-!-!-!-!-!"

# For the most common lowest-level errors
export RR_C_BANNER_ERROR_ITEM="!!!!!!!!!!!!!"



# Session Probe Types
##############################

export RR_C_DB_SESSION_MODE_QRY="READ_ONLY"
export RR_C_DB_SESSION_MODE_UPD="MODIFICATIONS"



# Cycle Modes for Jobs 
# *** not fully functional - might be pruned in future releases ***
##############################
#
#  template: "<mode>:interval"

export    RR_C_CYCLE_MINS="min:10"		; typeset -r RR_C_CYCLE_MINS
export  RR_C_CYCLE_HOURLY="hourly:1"		; typeset -r RR_C_CYCLE_HOURS
export   RR_C_CYCLE_DAILY="daily:1"		; typeset -r RR_C_CYCLE_DAILY
export  RR_C_CYCLE_WEEKLY="weekly:1"		; typeset -r RR_C_CYCLE_WEEKLY
export RR_C_CYCLE_MONTHLY="monthly:1"		; typeset -r RR_C_CYCLE_MONTHLY
#
# Only RR_C_CYCLE_MINS is active, and only for 10 min. periods.



# Run Level Settings
##############################

export RR_C_RUN_LEVEL_ALL="ALL"
export RR_C_RUN_LEVEL_BYPASS="SKIP"
export RR_C_RUN_LEVEL_INSTALL="INSTL"
export RR_C_RUN_LEVEL_OS="OS"
export RR_C_RUN_LEVEL_DB="DB"
export RR_C_RUN_LEVEL_APP="APP"
export RR_C_RUN_LEVEL_NET="NET"

export RR_C_RUN_LEVEL_LIST_CLASS="\
${RR_C_RUN_LEVEL_INSTALL}|\
${RR_C_RUN_LEVEL_OS}|\
${RR_C_RUN_LEVEL_NET}|\
${RR_C_RUN_LEVEL_DB}|\
${RR_C_RUN_LEVEL_APP}"

export RR_C_RUN_LEVEL_LIST_ACTION="SKIP|DEBUG"
export RR_C_RUN_LEVEL_LIST=\
"${RR_C_RUN_LEVEL_BYPASS}|${RR_C_RUN_LEVEL_ALL}|${RR_C_RUN_LEVEL_LIST_CLASS}|${RR_C_RUN_LEVEL_LIST_ACTION}"
#
# Above DEBUG action is not implemented but will be.
# Maybe in future: "NOMAIL|EXCLUDE"



# Alarm Types
##############################

#  Note: The alarm levels are in a particular alphabetic order
#

# For re-occurring alarms (not finished)
#export RR_C_ALARM_PROBLEM_AGAIN="RED2"
#export RR_C_ALARM_CAPACITYPLAN_AGAIN="PURPLE2" 
#export RR_C_ALARM_WARNING_AGAIN="PINK2"

export RR_C_ALARM_PROBLEM="RED"
export RR_C_ALARM_CAPACITYPLAN="PURPLE" 
export RR_C_ALARM_WARNING="PINK"
export RR_C_ALARM_INFORM="ORANGE" 
export RR_C_ALARM_FINE="GREEN" 
export RR_C_ALARM_BYPASS="BLUE" 

export RR_C_BAD_ALARM_LEVEL_LIST="\
${RR_C_ALARM_CAPACITYPLAN}|\
${RR_C_ALARM_WARNING}|\
${RR_C_ALARM_PROBLEM}"



# Threshold Settings
##############################

	
# OS Check Thresholds
#
# Percentages
export RR_C_LIMITPCT_OS_SPACE_FILSYS="$RR_C_ALARM_CAPACITYPLAN|91"	; typeset -ir RR_C_LIMITPCT_OS_SPACE_FILSYS


if [ -z "$RR_DB_TYPE" ] ; then
  export RR_DB_TYPE="$RR_C_DB_TYPE_SKIP"
fi

	
# DB Check Thresholds
#

case $RR_DB_TYPE in

$RR_C_DB_TYPE_SKIP )  ;;

$RR_C_DB_TYPE_HYBRID )

  # DB Percentages
  export RR_C_LIMITPCT_DB_PARAM_DATAFILES="$RR_C_ALARM_PROBLEM|96"
  export RR_C_LIMITPCT_DB_PARAM_ENQHIT="$RR_C_ALARM_PROBLEM|95"
  export RR_C_LIMITPCT_DB_PARAM_LOGHIST="$RR_C_ALARM_PROBLEM|96"  # not used
  export RR_C_LIMITPCT_DB_PARAM_OPENCUR="$RR_C_ALARM_PROBLEM|94"
  export RR_C_LIMITPCT_DB_PARAM_PROCESSES="$RR_C_ALARM_PROBLEM|94"
  export RR_C_LIMITPCT_DB_PARAM_SESSIONS="$RR_C_ALARM_PROBLEM|92"
  export RR_C_LIMITPCT_DB_PARAM_TRANXS="$RR_C_ALARM_PROBLEM|94"

  export RR_C_LIMITPCT_DB_RATIO_BUFHIT="$RR_C_ALARM_WARNING|85"
  export RR_C_LIMITPCT_DB_RATIO_DCTHIT="$RR_C_ALARM_WARNING|92"
  export RR_C_LIMITPCT_DB_RATIO_RBSHIT="$RR_C_ALARM_WARNING|99"
#  export RR_C_LIMITPCT_DB_RATIO_RBWRAP="$RR_C_ALARM_WARNING|00_00:10:00"  # not used, yet.

  export RR_C_LIMITPCT_DB_SPC_MAXEXTENTS="$RR_C_ALARM_PROBLEM|93"
  export RR_C_LIMITPCT_DB_SPC_DATAFILES="$RR_C_ALARM_PROBLEM|75"
  export RR_C_LIMITPCT_DB_SPC_TBLSPC="$RR_C_ALARM_PROBLEM|92"
  
  # DB Levels
  export RR_C_LIMIT_DB_RATIO_LOGSPCWAIT="$RR_C_ALARM_WARNING|1"
  # highest to lowest...
  export RR_C_LIMIT_DB_SESS_ELAPSED_QRY1="$RR_C_ALARM_PROBLEM|00_04:50:00,30000,null"   
  export RR_C_LIMIT_DB_SESS_ELAPSED_UPD1="$RR_C_ALARM_WARNING|00_00:50:00,10000,null"  
  export RR_C_LIMIT_DB_SESS_ELAPSED_UPD2="$RR_C_ALARM_PROBLEM|00_00:08:00,200,locked"  
  # Threshold info in the format: DD_HR:MI:SS,record_updates
  ;;

$RR_C_DB_TYPE_TRANSACTIONAL )

  # DB Percentages
  export RR_C_LIMITPCT_DB_PARAM_DATAFILES="$RR_C_ALARM_PROBLEM|96"
  export RR_C_LIMITPCT_DB_PARAM_ENQHIT="$RR_C_ALARM_PROBLEM|95"
  export RR_C_LIMITPCT_DB_PARAM_LOGHIST="$RR_C_ALARM_PROBLEM|96"  # not used
  export RR_C_LIMITPCT_DB_PARAM_OPENCUR="$RR_C_ALARM_PROBLEM|94"
  export RR_C_LIMITPCT_DB_PARAM_PROCESSES="$RR_C_ALARM_PROBLEM|94"
  export RR_C_LIMITPCT_DB_PARAM_SESSIONS="$RR_C_ALARM_PROBLEM|92"
  export RR_C_LIMITPCT_DB_PARAM_TRANXS="$RR_C_ALARM_PROBLEM|94"
 
  export RR_C_LIMITPCT_DB_RATIO_BUFHIT="$RR_C_ALARM_WARNING|88"
  export RR_C_LIMITPCT_DB_RATIO_DCTHIT="$RR_C_ALARM_WARNING|94"
  export RR_C_LIMITPCT_DB_RATIO_RBSHIT="$RR_C_ALARM_WARNING|99"
#  export RR_C_LIMITPCT_DB_RATIO_RBWRAP="$RR_C_ALARM_WARNING|00_00:10:00"  # not used, yet.

  export RR_C_LIMITPCT_DB_SPC_MAXEXTENTS="$RR_C_ALARM_PROBLEM|93"
  export RR_C_LIMITPCT_DB_SPC_DATAFILES="$RR_C_ALARM_PROBLEM|75"
  export RR_C_LIMITPCT_DB_SPC_TBLSPC="$RR_C_ALARM_PROBLEM|92"
  
  # DB Levels
  export RR_C_LIMIT_DB_RATIO_LOGSPCWAIT="$RR_C_ALARM_WARNING|1"
  export RR_C_LIMIT_DB_SESS_ELAPSED_QRY1="$RR_C_ALARM_PROBLEM|00_04:50:00,10000,null"   
  export RR_C_LIMIT_DB_SESS_ELAPSED_UPD1="$RR_C_ALARM_WARNING|00_00:50:00,10000,null"  
  export RR_C_LIMIT_DB_SESS_ELAPSED_UPD2="$RR_C_ALARM_PROBLEM|00_00:08:00,50,locked"  
  ;;

$RR_C_DB_TYPE_DATAWAREHOUSE )

  # DB Percentages
  export RR_C_LIMITPCT_DB_PARAM_DATAFILES="$RR_C_ALARM_PROBLEM|94"
  export RR_C_LIMITPCT_DB_PARAM_ENQHIT="$RR_C_ALARM_PROBLEM|95"
  export RR_C_LIMITPCT_DB_PARAM_LOGHIST="$RR_C_ALARM_PROBLEM|94" # not used
  export RR_C_LIMITPCT_DB_PARAM_OPENCUR="$RR_C_ALARM_PROBLEM|94"
  export RR_C_LIMITPCT_DB_PARAM_PROCESSES="$RR_C_ALARM_PROBLEM|94"
  export RR_C_LIMITPCT_DB_PARAM_SESSIONS="$RR_C_ALARM_PROBLEM|92"
  export RR_C_LIMITPCT_DB_PARAM_TRANXS="$RR_C_ALARM_PROBLEM|94"

  export RR_C_LIMITPCT_DB_RATIO_BUFHIT="$RR_C_ALARM_WARNING|78"
  export RR_C_LIMITPCT_DB_RATIO_DCTHIT="$RR_C_ALARM_WARNING|90"
  export RR_C_LIMITPCT_DB_RATIO_RBSHIT="$RR_C_ALARM_WARNING|99"
#  export RR_C_LIMITPCT_DB_RATIO_RBWRAP="$RR_C_ALARM_WARNING|00_00:10:00"  # not used, yet.
  
  export RR_C_LIMITPCT_DB_SPC_MAXEXTENTS="$RR_C_ALARM_PROBLEM|93"
  export RR_C_LIMITPCT_DB_SPC_DATAFILES="$RR_C_ALARM_PROBLEM|75"
  export RR_C_LIMITPCT_DB_SPC_TBLSPC="$RR_C_ALARM_PROBLEM|92"

  # DB Levels
  export RR_C_LIMIT_DB_RATIO_LOGSPCWAIT="$RR_C_ALARM_WARNING|1"
  export RR_C_LIMIT_DB_SESS_ELAPSED_QRY1="$RR_C_ALARM_PROBLEM|00_04:50:00,100000,null"   
  export RR_C_LIMIT_DB_SESS_ELAPSED_UPD1="$RR_C_ALARM_WARNING|00_00:50:00,10000,null"  
  export RR_C_LIMIT_DB_SESS_ELAPSED_UPD2="$RR_C_ALARM_WARNING|00_00:15:00,800,locked"  
  ;;
      
* )
  echo "${FUNCT_NAME}, Incorrect Database-type class supplied."
  return $RR_EXIT25
  ;;

esac



# Set to read-only
##############################

typeset -r RR_C_SQLDIR
typeset -r RR_C_TMPDIR
typeset -r RR_C_LOGDIR
typeset -r RR_C_MAILDIR
typeset -r RR_C_ARCDIR

if    [ "$RR_DB_TYPE" != "" ]  \
   && [ "$RR_DB_TYPE" != "$RR_C_DB_TYPE_SKIP" ]
then
  typeset -r RR_C_LIMITPCT_DB_PARAM_DATAFILES
  typeset -r RR_C_LIMITPCT_DB_PARAM_ENQHIT
  typeset -r RR_C_LIMITPCT_DB_PARAM_LOGHIST
  typeset -r RR_C_LIMITPCT_DB_PARAM_OPENCUR
  typeset -r RR_C_LIMITPCT_DB_PARAM_PROCESSES
  typeset -r RR_C_LIMITPCT_DB_PARAM_SESSIONS
  typeset -r RR_C_LIMITPCT_DB_PARAM_TRANXS
  typeset -r RR_C_LIMITPCT_DB_RATIO_BUFHIT
  typeset -r RR_C_LIMITPCT_DB_RATIO_DCTHIT
  typeset -r RR_C_LIMITPCT_DB_RATIO_RBSHIT
  # typeset -r RR_C_LIMITPCT_DB_RATIO_RBWRAP
  typeset -r RR_C_LIMITPCT_DB_SPC_DATAFILES
  typeset -r RR_C_LIMITPCT_DB_SPC_TBLSPC
  typeset -r RR_C_LIMITPCT_DB_SPC_MAXEXTENTS
  typeset -r RR_C_LIMIT_DB_RATIO_LOGSPCWAIT
fi

typeset -r RR_C_DB_TYPE_SKIP
typeset -r RR_C_DB_TYPE_HYBRID
typeset -r RR_C_DB_TYPE_TRANSACTIONAL
typeset -r RR_C_DB_TYPE_DATAWAREHOUSE

typeset -r RR_C_RUN_LEVEL_ALL
typeset -r RR_C_RUN_LEVEL_BYPASS
typeset -r RR_C_RUN_LEVEL_INSTALL
typeset -r RR_C_RUN_LEVEL_OS
typeset -r RR_C_RUN_LEVEL_DB
typeset -r RR_C_RUN_LEVEL_APP
typeset -r RR_C_RUN_LEVEL_NET

typeset -r RR_C_RUN_LEVEL_LIST_CLASS
typeset -r RR_C_RUN_LEVEL_LIST

typeset -r RR_C_ALARM_CAPACITYPLAN
typeset -r RR_C_ALARM_PROBLEM
typeset -r RR_C_ALARM_WARNING
typeset -r RR_C_ALARM_INFORM
typeset -r RR_C_ALARM_FINE
typeset -r RR_C_ALARM_BYPASS

typeset -r RR_C_BAD_ALARM_LEVEL_LIST

typeset -r RR_C_BASE_DIR
}

typeset -fx rr_constants_app





########
#
########
rr_constants_utl_exp()
{

# Setup exp parameter-file for use in exporting repository information from a particular database
#

test -n "$RR_C_SITE_NAME"	||  rr_constants_app;
ERRNR=$? ; test $ERRNR = 0	||  exit $ERRNR


if [ -z "$RR_ACTIVE_CFG_SQLFILE" ] ; then
  echo "
  RR_ACTIVE_CFG_SQLFILE must be set."
  return ${RR_EXIT3};
fi

if    [ -z "$ORACLE_SID" ]    \
   || [ "$ORACLE_SID" = "x" ]
then
  echo "
  ORACLE_SID must be set."
  return ${RR_EXIT3};
fi

(
echo "# Database settings for RedAlert export"
echo "userid=${RR_DB_ADMIN_LOGIN}/${RR_DB_ADMIN_PASWD}"
echo "file=${RR_C_ARCDIR}/${ORACLE_SID}.${RR_C_BAKREPOS_PARAM_FILE}.dmp"
echo "buffer=4096000"
echo "owner=(redalert)"
echo "grants=y"
echo "log=${RR_C_ARCDIR}/${ORACLE_SID}.${RR_C_BAKREPOS_PARAM_FILE}.log"
echo 
)  1>$RR_C_TMPDIR/${ORACLE_SID}.${RR_C_BAKREPOS_PARAM_FILE}.prm
}

typeset -fx rr_constants_utl_exp





########
#
########
rr_constants_setenv()
{
typeset FUNCT_NAME="rr_constants_setenv()"

rr_const_chk_env;
rr_runlevel_is_ok  $RR_RUN_LEVEL  || return $?


# Used for checking whether this has been invoked
RR_C_CONST_SETENV_LOAD='setenv_done'	; typeset -r RR_C_CONST_SETENV_LOAD


if [ -z "$RR_SCRIPT_NAME" ]; then
    ( echo "$RR_C_BANNER_ERROR_ITEM ${FUNCT_NAME}: Undefined variable \$RR_SCRIPT_NAME."
    ) |$RR_C_TEE -a $RR_LOGFILE
    return $RR_EXIT3
fi

# Used by function: sqlplus_exec_out_file()
           RR_C_SQLPLUS_ERR_FILE=$RR_C_SQLPLUS_ERR_FILE_PREFIX_${ORACLE_SID}_${RR_SCRIPT_NAME}.log
typeset -r RR_C_SQLPLUS_ERR_FILE


typeset RUNLVL_CLASS_LIST=`rr_runlevel_class_filter "$RR_RUN_LEVEL" ","`

typeset OLDIFS=$IFS
typeset IFS=','


# Across ALL platforms:
#
for i in  $RUNLVL_CLASS_LIST
do
   case "$i" in  
   
   "$RR_C_RUN_LEVEL_APP" )
      export RR_C_APP_CM_PROCESS_SRCH="LIBR"		; typeset -r RR_C_APP_CM_PROCESS_SRCH

      case "$RR_DB_APPL_VERSION" in
      11.* )
         export RR_C_APP_WRB_SRCH="wrb"			; typeset -r RR_C_APP_WRB_SRCH
         export RR_C_APP_FSRVR_PROCESS_LIST="f45srv"	; typeset -r RR_C_APP_FSRVR_PROCESS_LIST
         
         if [ $RR_APPL_ENV_CNT = 1 ]
         then
           # For single Apps install
           export RR_C_CONNECT_APPS="FNDFS_${RR_HOST}"
         else
           # For multiple Apps install
           export RR_C_CONNECT_APPS="${ORACLE_SID}_${RR_HOST}"
         fi
        ;;
         
      "10.7" )
         export RR_C_CONNECT_APPS="FNDFS_${RR_HOST}"
         ;;
      * )
         echo "${FUNCT_NAME}, RR_DB_APPL_VERSION needs to be set"
         return $RR_EXIT3
         ;;
      esac

      typeset -r RR_C_CONNECT_APPS
      ;;
      
   "$RR_C_RUN_LEVEL_DB" )
      ;;
      
   "$RR_C_RUN_LEVEL_NET" )
      ;;
      
   "$RR_C_RUN_LEVEL_OS" )
      ;;
      
   "$RR_C_RUN_LEVEL_INSTALL" )
      ;;
      
   * )
      echo "${FUNCT_NAME}, Incorrect Run-Level class supplied."
      return $RR_EXIT3
      ;;
   esac
done



case `SystemType` in

Windows_NT )      ######################################               
                  # Window NT Environment Settings
                  ######################################               
   

   # Across ALL run-levels under NT
   # (possible screening for target run-level at innvocation time)
   #
   export PATH="$ORACLE_HOME/bin;$PATH"
   export LD_LIBRARY_PATH="$ORACLE_HOME/lib;$LD_LIBRARY_PATH"
   
   export RR_C_ALERTLOG_TEMPLATE="@ALRT.LOG"

   case "$RR_ORCL_SW_VERSION" in
   "7.3" )  export     RR_C_LSNRCTL="$ORACLE_HOME/bin/lsnrctl"
            export     RR_C_TNSPING="$ORACLE_HOME/bin/tnsping"
            export      RR_C_SVRMGR="$ORACLE_HOME/bin/svrmgr23"
            export     RR_C_SQLPLUS="$ORACLE_HOME/bin/plus33"
            export         RR_C_IMP="$ORACLE_HOME/bin/imp33"
            export         RR_C_EXP="$ORACLE_HOME/bin/exp33"
            ;; 
  "8.0" )   export     RR_C_LSNRCTL="$ORACLE_HOME/bin/lsnrctl80"
            export     RR_C_TNSPING="$ORACLE_HOME/bin/tnsping80"
            export      RR_C_SVRMGR="$ORACLE_HOME/bin/svrmgr30"
            export     RR_C_SQLPLUS="$ORACLE_HOME/bin/plus80"
            ;;
   * )      echo "${FUNCT_NAME}, RR_ORCL_SW_VERSION needs to be set"
            return $RR_EXIT3
            ;;
   esac


   for i in $RUNLVL_CLASS_LIST
   do
      case $i in
      
      $RR_C_RUN_LEVEL_APP )

         export RR_C_APP_CM_PROCESS_LIST="FNDLIBR.EXE FND CPMGR"  ; typeset -r RR_C_APP_CM_PROCESS_LIST

         case "$RR_DB_APPL_VERSION" in
         "11.1" )
            ;;
         "11.0" )
            export RR_C_APP_WRB_PROCESS_LIST="wrbcfg wrblog wrbroker wrbfac wrbvpm wrbasrv wrbahsrv"
            typeset -r RR_C_APP_WRB_PROCESS_LIST
            
            export RR_C_APP_WWWLSNR_PROCESS="sv${ORACLE_SID}"   ;  typeset -r RR_C_APP_WWWLSNR_PROCESS
            ;;
         "10.7" )
            ;;
         * )
            echo "${FUNCT_NAME}, RR_DB_APPL_VERSION needs to be set"
            return $RR_EXIT3
            ;;
         esac
         ;;
      
      $RR_C_RUN_LEVEL_DB )
         ;;
      
      $RR_C_RUN_LEVEL_NET )
         ;;
      
      $RR_C_RUN_LEVEL_OS )
         ;;
      
      $RR_C_RUN_LEVEL_INSTALL )
         ;;
         
      * )
         echo "${FUNCT_NAME}, Incorrect Run-Level class supplied."
         return $RR_EXIT3
         ;;
      esac
   done
   ;;
   
* )               #################################               
   ;;
esac

IFS=$OLDIFS


# Final Environment Checks...

if [ ! -f "$RR_C_GLOGIN" ] ; then
    ( echo "$RR_C_BANNER_ERROR_ITEM ${FUNCT_NAME}: Incorrect parameter \$ORACLE_HOME supplied"
      echo "Please fix the configuration file." \
    ) 2>&1 |$RR_C_TEE -a $RR_LOGFILE
    return $RR_EXIT19
fi


typeset -r PATH
typeset -r LD_LIBRARY_PATH

typeset -r RR_C_LSNRCTL
typeset -r RR_C_TNSPING
typeset -r RR_C_SVRMGR
typeset -r RR_C_SQLPLUS
typeset -r RR_C_IMP
typeset -r RR_C_EXP
typeset -r RR_C_SPLUS
typeset -r RR_C_GLOGIN
typeset -r RR_C_RDBMS

typeset -r ORA_NLS
typeset -r ORA_NLS32
typeset -r ORA_NLS33
}

typeset -fx rr_constants_setenv

