#!/bin/bash
#set -vx
#  
# Description:
#   Run-level processing functions. Defined in configuration file.
#
#
#  Author: Tom Jurcic
#  Date:   09/10/2000
#
##############################################################################




#----------------------------------------------------------------------------

##############################################################################
#
# Global Constants
#
##############################################################################


#
# Module Name
#
RR_C_MOD_NAME_RUNLVL="rr_lib_runlevel"
typeset -r RR_C_MOD_NAME_RUNLVL




#----------------------------------------------------------------------------

##############################################################################
#
# import modules
#
##############################################################################


. ./rr_lib_constants.sh



# Apply constants only if not already loaded
#
test -n "$RR_C_SITE_NAME"	||  rr_constants_app;
ERRNR=$? ; test $ERRNR = 0	||  exit $ERRNR






#----------------------------------------------------------------------------

##############################################################################
#
# local functions
#
##############################################################################




########
#
########
rr_runlevel_usage()
{
2>&1 \ 
(
echo "${0},rr_runlevel_usage:" 
echo "Usage :  ${0}  ... ";
echo "Example: ${0} ";
echo "
   RR_RUN_LEVEL must be set.
   This variable can be set from the environment or passed as an argument.
   RR_RUN_LEVEL is the target functionality that \"${0}\" will 
   use to monitor the local database/s.
" 
) 

sleep 3
return ${RR_EXIT1};
}

typeset -fx rr_runlevel_usage




########
#
########
rr_runlevel_chk_env()
{
if [ -z "$RR_RUN_LEVEL" ]; then
    rr_runlevel_usage;
    return ${RR_EXIT3};
fi
}

typeset -fx rr_runlevel_chk_env




#--------------------------------------------------------------------

##############################################################################
#
# main routine
#
##############################################################################





########
#
# Making sure the correct run-level value has been supplied.
#
########
rr_runlevel_is_ok()
{
# Local Argument Variables
#
typeset RUN_LVL="$1"

if [ $# -ne 1 ]
then
  return $RR_EXIT7
fi

rr_runlevel_chk_env;

typeset IFS=','

eval "
for i in  \$RUN_LVL
do
  #echo "\$i"
  case "\$i" in
    $RR_C_RUN_LEVEL_LIST ) :                ;;
    * )                    return $RR_EXIT17  ;; 
  esac
done
"
}

typeset -fx rr_runlevel_is_ok





########
#
########
rr_runlevel_class_filter()
{
# Local Argument Variables
#
typeset   RUN_LVL="$1"
typeset DELIMITER="$2"

if [ $# -ne 2 ]
then
  return $RR_EXIT7
fi

#rr_runlevel_chk_env;


typeset FILTER_LIST=""
typeset OLDIFS=$IFS
typeset CHK_RUN_LVL="$RUN_LVL"

case "$RUN_LVL" in
  *${RR_C_RUN_LEVEL_ALL}* )
    CHK_RUN_LVL="$RR_C_RUN_LEVEL_LIST_CLASS"
    typeset IFS='|'
    ;;
  * )  typeset IFS=','
    ;;
esac

eval "
for i in  \$CHK_RUN_LVL
do
  case "\$i" in
  $RR_C_RUN_LEVEL_INSTALL )
     case "\$RUN_LVL" in
     *\${RR_C_RUN_LEVEL_ALL}* )
        continue
        ;;
     * )
        if [ \"\$FILTER_LIST\" = \"\" ]
        then
          FILTER_LIST=\`echo \"\$i\"\`
        else
          FILTER_LIST=\`echo \"\${FILTER_LIST}\${DELIMITER}\$i\"\`
        fi
        ;; 
     esac
     ;;
  $RR_C_RUN_LEVEL_LIST_CLASS )
     if [ \"\$FILTER_LIST\" = \"\" ]
     then
       FILTER_LIST=\`echo \"\$i\"\`
     else
       FILTER_LIST=\`echo \"\${FILTER_LIST}\${DELIMITER}\$i\"\`
     fi
     ;;
  * )  :
    ;; 
  esac
done
"
IFS=$OLDIFS
echo "$FILTER_LIST"
}

typeset -fx rr_runlevel_class_filter





########
#
########
rr_runlevel_class_find()
{
#set -vx

# Local Argument Variables
#
typeset RUN_LVL="$1"
typeset TARGET_CLASS="$2"

if [ $# -ne 2 ]
then
  return $RR_EXIT7
fi

#rr_runlevel_chk_env;

# Make sure the correct run-level values are supplied
#

typeset RUN_LVL_CLASS=""
RUN_LVL_CLASS=`rr_runlevel_class_filter "$RUN_LVL" ","`

# Check if TARGET_CLASS is in the filtered RUN LEVEL list
#
case "$RUN_LVL_CLASS" in
  *${TARGET_CLASS}* )  :
  ;;
  * )  return $RR_EXIT16
  ;;
esac
}

typeset -fx rr_runlevel_class_find

